/*
 * Images.cs - Manages the application icons and bitmaps.
 *
 * Copyright (C) 2004 - 2011 Andreas Scherrer
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */

using System;
using System.Drawing;

namespace Level9
{
	/// <summary>
	/// Manages the application icons and bitmaps.
	/// </summary>
	public class Images
	{
		// -- Enums ----------------------------------------------------------

		/// <summary>
		/// The available image names.
		/// </summary>
		public enum Stock
		{
			/// <summary>
			/// 'About' icon; size: 16 x 16 pixels.
			/// </summary>
			About_16x16,
			/// <summary>
			/// 'Accept' icon; size: 16 x 16 pixels.
			/// </summary>
			Accept_16x16,
			/// <summary>
			/// 'Close' icon; size: 16 x 16 pixels.
			/// </summary>
			Close_16x16,
			/// <summary>
			/// 'Copy' icon; size: 16 x 16 pixels.
			/// </summary>
			Copy_16x16,
			/// <summary>
			/// 'Dictionary' icon; size: 16 x 16 pixels.
			/// </summary>
			Dictionary_16x16,
			/// <summary>
			/// 'Down' icon; size: 16 x 16 pixels.
			/// </summary>
			Down_16x16,
			/// <summary>
			/// 'Execute' icon; size: 16 x 16 pixels.
			/// </summary>
			Execute_16x16,
			/// <summary>
			/// 'Exit' icon; size: 16 x 16 pixels.
			/// </summary>
			Exit_16x16,
			/// <summary>
			/// 'Fullscreen' icon; size: 16 x 16 pixels.
			/// </summary>
			Fullscreen_16x16,
			/// <summary>
			/// 'Help' icon; size: 16 x 16 pixels.
			/// </summary>
			Help_16x16,
			/// <summary>
			/// 'L9Cut' icon; size: 16 x 16 pixels.
			/// </summary>
			L9cut_16x16,
			/// <summary>
			/// Blank icon; size: 16 x 16 pixels.
			/// </summary>
			Null_16x16,
			/// <summary>
			/// 'Open' icon; size: 16 x 16 pixels.
			/// </summary>
			Open_16x16,
			/// <summary>
			/// 'Pause' icon; size: 16 x 16 pixels.
			/// </summary>
			Pause_16x16,
			/// <summary>
			/// 'Play' icon; size: 16 x 16 pixels.
			/// </summary>
			Play_16x16,
			/// <summary>
			/// 'Restore' icon; size: 16 x 16 pixels.
			/// </summary>
			Restore_16x16,
			/// <summary>
			/// 'Save' icon; size: 16 x 16 pixels.
			/// </summary>
			Save_16x16,
			/// <summary>
			/// 'Save position' icon; size: 16 x 16 pixels.
			/// </summary>
			Savepos_16x16,
			/// <summary>
			/// 'Scripts' icon; size: 16 x 16 pixels.
			/// </summary>
			Scripts_16x16,
			/// <summary>
			/// Script editor: 'Control: Play' icon; size: 16 x 16 pixels.
			/// </summary>
			Script_Play_16x16,
			/// <summary>
			/// Script editor: 'Control: Stop' icon; size: 16 x 16 pixels.
			/// </summary>
			Script_Stop_16x16,
			/// <summary>
			/// Script editor: 'Control: Pause' icon; size: 16 x 16 pixels.
			/// </summary>
			Script_Pause_16x16,
			/// <summary>
			/// Script editor: 'Remove Control' icon; size: 16 x 16 pixels.
			/// </summary>
			Script_Remove_Control_16x16,
			/// <summary>
			/// Script editor: 'Insert row' icon; size: 16 x 16 pixels.
			/// </summary>
			Script_Insert_Row_16x16,
			/// <summary>
			/// Script editor: 'Delete row(s)' icon; size: 16 x 16 pixels.
			/// </summary>
			Script_Delete_Rows_16x16,
			/// <summary>
			/// 'Scrollback' icon; size: 16 x 16 pixels.
			/// </summary>
			Scrollback_16x16,
			/// <summary>
			/// 'Settings' icon; size: 16 x 16 pixels.
			/// </summary>
			Settings_16x16,
			/// <summary>
			/// 'Stop' icon; size: 16 x 16 pixels.
			/// </summary>
			Stop_16x16,
			/// <summary>
			/// 'Trash' icon; size: 16 x 16 pixels.
			/// </summary>
			Trash_16x16,
			/// <summary>
			/// 'Up' icon; size: 16 x 16 pixels.
			/// </summary>
			Up_16x16,
			/// <summary>
			/// 'Record' icon (active); size: 16 x 16 pixels.
			/// </summary>
			Record_48x48,
			/// <summary>
			/// 'Record' icon (inactive); size: 16 x 16 pixels.
			/// </summary>
			Record_Grey_48x48,
			/// <summary>
			/// 'Colors' icon; size: 48 x 48 pixels.
			/// </summary>
			Colors_48x48,
			/// <summary>
			/// 'Font' icon; size: 48 x 48 pixels.
			/// </summary>
			Font_48x48,
			/// <summary>
			/// 'Graphics' icon; size: 48 x 48 pixels.
			/// </summary>
			Graphics_48x48,
			/// <summary>
			/// 'L9Cut' icon; size: 48 x 48 pixels.
			/// </summary>
			L9cut_48x48,
			/// <summary>
			/// Splash image; size: 300 x 93 pixels.
			/// </summary>
			Splash_300x93,
		};

		// -- Attributes -----------------------------------------------------

		/// <summary>
		/// The image resource names.
		/// </summary>
		static string[] resources =
		{
			"about_16x16",
			"accept_16x16",
			"close_16x16",
			"copy_16x16",
			"dictionary_16x16",
			"down_16x16",
			"execute_16x16",
			"exit_16x16",
			"fullscreen_16x16",
			"help_16x16",
			"l9cut_16x16",
			"null_16x16",
			"open_16x16",
			"pause_16x16",
			"play_16x16",
			"restore_16x16",
			"save_16x16",
			"savepos_16x16",
			"scripts_16x16",
			"script_play_16x16",
			"script_stop_16x16",
			"script_pause_16x16",
			"script_remove_control_16x16",
			"script_insert_row_16x16",
			"script_delete_rows_16x16",
			"scrollback_16x16",
			"settings_16x16",
			"stop_16x16",
			"trash_16x16",
			"up_16x16",
			"record_48x48",
			"record_grey_48x48",
			"colors_48x48",
			"font_48x48",
			"graphics_48x48",
			"l9cut_48x48",
			"splash_300x93",
		};

		/// <summary>
		/// A list with Image elements.
		/// </summary>
		static Image[] images;

		// -- Constructors ---------------------------------------------------

		/// <summary>
		/// Initializes static members of the Images class.
		/// </summary>
		static Images()
		{
			images = new Image[resources.Length];
			try {
				System.Resources.ResourceManager manager =
					new System.Resources.ResourceManager(typeof(Images));

				for (int i = 0; i < resources.Length; i++) {
					Image image = (Image)manager.GetObject(resources[i]);
					if (image != null) {
						images[i] = image;
					}
				}
			}
			catch(Exception e) {
				ErrorHandler.Handle(typeof(Images),
					"Error getting bitmap resource.", e);
			}
		}

		// -- Methods --------------------------------------------------------

		/// <summary>
		/// Provides an image for the given name.
		/// </summary>
		/// <param name="imageName">the image name</param>
		/// <returns>the image, or null if an error occurred</returns>
		public static Image Get(Stock imageName)
		{
			return images[(int)imageName];
		}
	}
}
